<?php

namespace App\Http\Controllers;

use App\Models\Categorie;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;

class CategorieAdminController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $categories = Categorie::all();
        return view('part.admin.categorie.index')->with('categories', $categories);
    }



    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request) //Création d'une nouvelle catégorie
    {

        $request->validate([
            'nom' => 'required|unique:categories|max:255',
        ]);

        $categorie = new Categorie;
        $categorie->nom = $request->nom;
        $save = $categorie->save();

        if($save != null){
            $message = 'La catégorie a été bien créée.';
            return back()->with('message', $message);
        }else{
            $error = 'Un problème est survenu.';
            return back()->with('error', $error);
        }
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        //
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $categorie = Categorie::find($id);
        $categorie->nom = $request->nom;
        $save = $categorie->save();
        if($save != null){
            $message = 'La catégorie a été bien modifiée.';
            return back()->with('message', $message);
        }else{
            $error = 'Un problème est survenu.';
            return back()->with('error', $error);
        }
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        $categorie = Categorie::find($id);
        $delete = $categorie->delete();
        if($delete != null){
            $message = 'La catégorie a été bien supprimée.';
            return back()->with('message', $message);
        }else{
            $error = 'Un problème est survenu.';
            return back()->with('error', $error);
        }
    }
}
